package com.webchat.aigc.service;

import com.webchat.common.bean.APIResponseBean;
import com.webchat.common.bean.APIResponseBeanUtil;
import com.webchat.common.util.JsonUtil;
import com.webchat.domain.vo.response.UserBaseResponseInfoVO;
import com.webchat.domain.vo.response.UserBaseResponseVO;
import com.webchat.rmi.user.UserServiceClient;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Slf4j
@Service
public class UserService {

    @Autowired
    private UserServiceClient userServiceClient;

    public UserBaseResponseInfoVO accountInfo(String account) {
        APIResponseBean<UserBaseResponseInfoVO> responseBean = userServiceClient.userInfo(account);
        if (APIResponseBeanUtil.isOk(responseBean)) {
            return responseBean.getData();
        }
        log.error("获取用户信息远程调用异常 =====> account:{}, response:{}", account, JsonUtil.toJsonString(responseBean));
        return null;
    }

    /**
     * 根据用户名查询用户基础信息
     *
     * @param name
     * @return
     */
    public UserBaseResponseVO accountInfoByName(String name) {
        APIResponseBean<UserBaseResponseVO> responseBean = userServiceClient.userNameBaseInfo(name);
        if (APIResponseBeanUtil.isOk(responseBean)) {
            return responseBean.getData();
        }
        log.error("获取用户信息远程调用异常 =====> name:{}, response:{}", name, JsonUtil.toJsonString(responseBean));
        return null;
    }

}
