package com.webchat.client.chat.controller;


import com.webchat.client.chat.service.AccountService;
import com.webchat.client.chat.service.UserSessionService;
import com.webchat.common.bean.APIResponseBean;
import com.webchat.common.bean.APIResponseBeanUtil;
import com.webchat.common.helper.SessionHelper;
import com.webchat.domain.vo.response.UserBaseResponseInfoVO;
import jakarta.servlet.http.HttpServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/client-service/chat/account")
public class AccountController {

    @Autowired
    private AccountService userService;

    @Autowired
    private UserSessionService userSessionService;

    @Autowired
    private HttpServletRequest request;

    @Value("${oauth.server-url}")
    private String logoutServer;

    @GetMapping("/current/info")
    public APIResponseBean<UserBaseResponseInfoVO> getCurrentUserInfo() {
        String userId = SessionHelper.getCurrentUserId();
        return APIResponseBeanUtil.success(userService.userInfo(userId));
    }

    /**
     * 退出登录
     *
     * @return
     */
    @GetMapping("/logout")
    public APIResponseBean<String> logout() {
        userSessionService.logout(request);
        String ssoServerUrl = String.format(logoutServer, request.getHeader("origin-url"));
        return APIResponseBeanUtil.success(ssoServerUrl);
    }

    /**
     *
     * @return
     */
    @GetMapping("/query")
    public APIResponseBean<UserBaseResponseInfoVO> queryAccount(@RequestParam String account) {

        return APIResponseBeanUtil.success(userService.queryAccount(account));
    }

}
