package com.webchat.client.chat.controller;


import com.webchat.client.chat.service.MomentService;
import com.webchat.common.bean.APIResponseBean;
import com.webchat.common.bean.APIResponseBeanUtil;
import com.webchat.common.config.annotation.SafeClick;
import com.webchat.common.enums.ClickEvent;
import com.webchat.common.helper.SessionHelper;
import com.webchat.domain.vo.request.MomentSaveOrUpdateVO;
import com.webchat.domain.vo.response.moment.MomentDetailVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@RequestMapping("/client-service/moment")
public class MomentController {


    @Autowired
    private MomentService momentService;

    /**
     * 发布动态
     *
     * @return
     */
    @SafeClick(event = ClickEvent.PUBLISH_MOMENT, time = 2000, message = "动态发布中，请勿重复操作")
    @PostMapping("/publish")
    public APIResponseBean<Long> publish(@RequestBody MomentSaveOrUpdateVO momentSaveOrUpdate) {

        momentSaveOrUpdate.validateRequestParam();

        String author = SessionHelper.getCurrentUserId();
        momentSaveOrUpdate.setAuthor(author);
        // 客户端ip
        String clientIp = SessionHelper.getCurrentClientIP();
        momentSaveOrUpdate.setIp(clientIp);
        Long momentId = momentService.publish(momentSaveOrUpdate);
        return APIResponseBeanUtil.success(momentId);
    }

    /**
     * 朋友圈动态列表加载
     *
     * @param lastMomentId
     * @param size
     * @return
     */
    @GetMapping("/timeline")
    APIResponseBean<List<MomentDetailVO>> timeline(@RequestParam Long lastMomentId,
                                                   @RequestParam(value = "size", defaultValue = "10") Integer size) {
        String userId = SessionHelper.getCurrentUserId();
        return APIResponseBeanUtil.success(momentService.timeline(userId, lastMomentId, size));
    }
}
