package com.webchat.client.chat.service;

import com.webchat.common.bean.APIResponseBean;
import com.webchat.common.bean.APIResponseBeanUtil;
import com.webchat.common.exception.BusinessException;
import com.webchat.domain.vo.request.MomentSaveOrUpdateVO;
import com.webchat.domain.vo.response.moment.MomentDetailVO;
import com.webchat.rmi.ugc.MomentClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;

@Service
public class MomentService {


    @Autowired
    private MomentClient momentClient;

    /**
     * 发布动态
     * @param momentSaveOrUpdateVO
     * @return
     */
    public Long publish(MomentSaveOrUpdateVO momentSaveOrUpdateVO) {

        // RPC 请求UGC微服务实现朋友圈动态发布核心流程
        APIResponseBean<Long> responseBean = momentClient.publish(momentSaveOrUpdateVO);
        if (APIResponseBeanUtil.isOk(responseBean)) {
            return responseBean.getData();
        }
        throw new BusinessException(responseBean.getMsg());
    }

    /**
     * 朋友圈动态列表加载
     *
     * @param userId
     * @param lastMomentId
     * @param size
     * @return
     */
    public List<MomentDetailVO> timeline(String userId, Long lastMomentId, int size) {

        APIResponseBean<List<MomentDetailVO>> responseBean = momentClient.timeline(userId, lastMomentId, size);
        if (APIResponseBeanUtil.isOk(responseBean)) {
            return responseBean.getData();
        }
        return Collections.emptyList();
    }
}
