package com.webchat.common.service.messagequeue.producer;

import com.webchat.common.enums.messagequeue.MessageBroadChannelEnum;
import com.webchat.common.enums.messagequeue.MessageQueueEnum;
import com.webchat.common.exception.BusinessException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.stereotype.Service;

@RefreshScope
@Service
public class MessageQueueProducer<T, P> {

    @Autowired
    private RocketMessageQueueSender<T, P> rocketMessageQueueSender;

    @Autowired
    private RedisMessageQueueSender<T, P> redisMessageQueueSender;

    /**
     * 消息队列开关配置，支持：rocketmq、redis、kafka等
     */
    @Value("${message-queue.used:redis}")
    private String messageQueueUsed;

    /**
     * 普通队列消息发送
     *
     * @param queue
     * @param message
     */
    public void send(MessageQueueEnum queue, T message) {

        this.getSender().send(queue, message);
    }

    /**
     * 优先级队列消息发送
     *
     * @param queue
     * @param message
     * @param priority
     */
    public void prioritySend(MessageQueueEnum queue, T message, P priority) {

        this.getSender().prioritySend(queue, message, priority);
    }

    /**
     * 广播消息发送
     *
     * @param channel
     * @param message
     */
    public void broadSend(MessageBroadChannelEnum channel, T message) {

        this.getSender().broadSend(channel, message);
    }

    private AbstractMessageQueueSender<T, P> getSender() {
        if (messageQueueUsed.equals("rocketmq")) {
            return rocketMessageQueueSender;
        } else if (messageQueueUsed.equals("redis")) {
            return redisMessageQueueSender;
        }
        throw new BusinessException("不支持的队列类型！");
    }
}
