package com.webchat.pgc.service;

import com.webchat.common.bean.APIResponseBean;
import com.webchat.common.bean.APIResponseBeanUtil;
import com.webchat.common.enums.AccountRelationTypeEnum;
import com.webchat.domain.vo.response.UserBaseResponseInfoVO;
import com.webchat.rmi.user.UserServiceClient;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Set;

@Service
public class AccountService {

    @Autowired
    private UserServiceClient userServiceClient;

    /**
     * 查询当前账号信息
     *
     * @param account
     * @return
     */

    public UserBaseResponseInfoVO accountInfo(String account) {

        APIResponseBean<UserBaseResponseInfoVO> responseBean = userServiceClient.userInfo(account);
        if (APIResponseBeanUtil.isOk(responseBean)) {
            return responseBean.getData();
        }
        return null;
    }

    /**
     *  批量查询账号详情数据
     *
     * @param accounts
     * @return
     */
    public List<UserBaseResponseInfoVO> batchGet(List<String> accounts) {
        if (CollectionUtils.isEmpty(accounts)) {
            return Collections.emptyList();
        }
        APIResponseBean<List<UserBaseResponseInfoVO>> responseBean =
                userServiceClient.batchGet(accounts);
        if (APIResponseBeanUtil.isOk(responseBean)) {
            return responseBean.getData();
        }
        throw new RuntimeException(responseBean.getMsg());
    }

    public Map<String, UserBaseResponseInfoVO> batchGet(Set<String> accounts) {
        if (CollectionUtils.isEmpty(accounts)) {
            return Collections.emptyMap();
        }
        APIResponseBean<Map<String, UserBaseResponseInfoVO>> responseBean =
                userServiceClient.batchGet(accounts);
        if (APIResponseBeanUtil.isOk(responseBean)) {
            return responseBean.getData();
        }
        throw new RuntimeException(responseBean.getMsg());
    }

    /**
     * 获取群组下的群成员用户id集合
     *
     * @param groupAccount
     * @return
     */
    public Set<String> getGroupUserIds(String groupAccount) {
        APIResponseBean<Set<String>> responseBean =
                userServiceClient.getAllSubscriberByAccount(AccountRelationTypeEnum.USER_GROUP.getType(), groupAccount);
        if (APIResponseBeanUtil.isOk(responseBean)) {
            return responseBean.getData();
        }
        return null;
    }
}
