package com.webchat.ugc.controller;

import com.webchat.common.bean.APIResponseBean;
import com.webchat.common.bean.APIResponseBeanUtil;
import com.webchat.domain.vo.request.ChattingRequestVO;
import com.webchat.domain.vo.request.mess.ChatMessageRequestVO;
import com.webchat.domain.vo.response.chatting.ChattingListResponseVO;
import com.webchat.domain.vo.response.mess.ChatMessageResponseVO;
import com.webchat.rmi.ugc.ChatMessageClient;
import com.webchat.ugc.messaegqueue.service.PersistentMessageService;
import com.webchat.ugc.service.ChatMessageService;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@RestController
public class ChatMessageController implements ChatMessageClient {


    @Autowired
    private ChatMessageService chatMessageService;

    @Autowired
    private PersistentMessageService persistentMessageService;

    /**
     * 查询用户对话列表
     *
     * @param userId        当前登录用户uid
     * @param lastChatTime  开始查询时间
     * @param size          最大获取对话列表条数
     * @return
     */
    @Override
    public APIResponseBean<List<ChattingListResponseVO>> listChatting(
            @PathVariable String userId, Long lastChatTime, Integer size) {

        return APIResponseBeanUtil.success(chatMessageService.listChatting(userId, lastChatTime, size));
    }

    @Override
    public APIResponseBean<Boolean> addChattingList(@RequestBody @Valid ChattingRequestVO chattingRequest) {

        return APIResponseBeanUtil.success(chatMessageService.addChattingList(chattingRequest));
    }

    @Override
    public APIResponseBean<List<ChatMessageResponseVO>> list(String sourceAccount, String targetAccount, Integer size, Long lastId, Long fixedMessageId) {
        List<ChatMessageResponseVO> chatMessages= persistentMessageService.getChatMessListFromCache(sourceAccount, targetAccount, lastId, fixedMessageId, size);
        return APIResponseBeanUtil.success(chatMessages);
    }

    @Override
    public APIResponseBean<List<String>> query(String sourceUserId, String targetUserId,
                                               Long startTime, Long endTime, Integer count) {

        List<String> messages = persistentMessageService.query(sourceUserId, targetUserId, startTime, endTime, count);
        return APIResponseBeanUtil.success(messages);
    }
}
